==> classic-theme-restorer_1.4.9.orig.tar.gz: classic-theme-restorer-1.4.9/xpi/defaults/preferences/options.js <==
// tab settings
pref("extensions.classicthemerestorer.tabs","tabs_squared");
pref("extensions.classicthemerestorer.tabsontop",'unset');
pref("extensions.classicthemerestorer.ctabheightcb",false);
pref("extensions.classicthemerestorer.square_edges",false);
pref("extensions.classicthemerestorer.ctabheight",28);
pref("extensions.classicthemerestorer.ctabmwidth",100);
pref("extensions.classicthemerestorer.ctabwidth",210);
pref("extensions.classicthemerestorer.emptyfavico_t",'emptyfavico_t_none');
pref("extensions.classicthemerestorer.noemptypticon",false);
pref("extensions.classicthemerestorer.closetab","closetab_default");
pref("extensions.classicthemerestorer.closetabhfl",false);
pref("extensions.classicthemerestorer.closeonleft",false);
pref("extensions.classicthemerestorer.closetabbig",false);
pref("extensions.classicthemerestorer.closeicon",'closeicon_default');
pref("extensions.classicthemerestorer.tttitlebar",false);

//Appbutton settings
pref("extensions.classicthemerestorer.appbutton",'appbutton_v1');
pref("extensions.classicthemerestorer.appbuttonc",'appbuttonc_orange');
pref("extensions.classicthemerestorer.appbuttonct",false);
pref("extensions.classicthemerestorer.altabico",'altabico_white');
pref("extensions.classicthemerestorer.appbutmhi",false);
pref("extensions.classicthemerestorer.appbutbdl",false);
pref("extensions.classicthemerestorer.dblclclosefx",false);
pref("extensions.classicthemerestorer.appbclmmenus",true);
pref("extensions.classicthemerestorer.appbautocol",false);

pref("extensions.classicthemerestorer.appbuttontxt",'');

pref("extensions.classicthemerestorer.cappbutc1",'#00FF00');
pref("extensions.classicthemerestorer.cappbutc2",'#007700');

//General UI
pref("extensions.classicthemerestorer.smallnavbut",false);
pref("extensions.classicthemerestorer.bfurlbarfix",false);
pref("extensions.classicthemerestorer.bf_space",false);
pref("extensions.classicthemerestorer.backforward",false);
pref("extensions.classicthemerestorer.hide_bf_popup",false);
pref("extensions.classicthemerestorer.nbcompact",false);
pref("extensions.classicthemerestorer.statusbar",true);
pref("extensions.classicthemerestorer.noconicons",false);
pref("extensions.classicthemerestorer.altoptions",'options_default');
pref("extensions.classicthemerestorer.svgfilters",false);
pref("extensions.classicthemerestorer.combrelstop",false);
pref("extensions.classicthemerestorer.activndicat",false);
pref("extensions.classicthemerestorer.nbisizedelay",0);
pref("extensions.classicthemerestorer.findbar","findbar_default");
pref("extensions.classicthemerestorer.nav_txt_ico","icons");
pref("extensions.classicthemerestorer.iat_notf_vt",false);
pref("extensions.classicthemerestorer.wincontrols",false);
pref("extensions.classicthemerestorer.oldtoplevimg",false);
pref("extensions.classicthemerestorer.altalertbox",false);
pref("extensions.classicthemerestorer.emptyfavico_g",'emptyfavico_g_def');
pref("extensions.classicthemerestorer.panelmenucol",false);
pref("extensions.classicthemerestorer.cpanelmenus",false);
pref("extensions.classicthemerestorer.hidezoomres",false);
pref("extensions.classicthemerestorer.alt_newtabp",false);
pref("extensions.classicthemerestorer.ctroldsearch",false);
pref("extensions.classicthemerestorer.ctroldsearchc",false);
pref("extensions.classicthemerestorer.osearch_meoit",false);
pref("extensions.classicthemerestorer.osearch_dm",false);
pref("extensions.classicthemerestorer.addonversion",false);
pref("extensions.classicthemerestorer.alt_addonsm",false);
pref("extensions.classicthemerestorer.am_nowarning",false);
pref("extensions.classicthemerestorer.am_compact",false);
pref("extensions.classicthemerestorer.am_compact2",true);
pref("extensions.classicthemerestorer.am_highlight",false);
pref("extensions.classicthemerestorer.am_buticons",false);
pref("extensions.classicthemerestorer.am_hovshowb",false);
pref("extensions.classicthemerestorer.alt_addonsp",false);
pref("extensions.classicthemerestorer.hiderecentbm",false);
pref("extensions.classicthemerestorer.hideeditbm",false);
pref("extensions.classicthemerestorer.bmbutpanelm",false);
pref("extensions.classicthemerestorer.bmbunsortbm",false);
pref("extensions.classicthemerestorer.bmbunsortbm2",true);
pref("extensions.classicthemerestorer.bmbviewbmtb",false);
pref("extensions.classicthemerestorer.bmbnounsort",false);
pref("extensions.classicthemerestorer.bmbutnotext",false);
pref("extensions.classicthemerestorer.skipprintpr",false);
pref("extensions.classicthemerestorer.tbconmenu",false);
pref("extensions.classicthemerestorer.noresizerxp",false);
pref("extensions.classicthemerestorer.pmhidelabels",false);
pref("extensions.classicthemerestorer.menupopupscr",false);
pref("extensions.classicthemerestorer.hideprivmask",false);
pref("extensions.classicthemerestorer.urlresults",false);

pref("extensions.classicthemerestorer.tabmokcolor",false);
pref("extensions.classicthemerestorer.tabmokcolor2",false);
pref("extensions.classicthemerestorer.tabmokcolor3",false);
pref("extensions.classicthemerestorer.tabmokcolor4",false);

pref("extensions.classicthemerestorer.invicomenubar",false);
pref("extensions.classicthemerestorer.invicotabsbar",false);
pref("extensions.classicthemerestorer.inviconavbar",false);
pref("extensions.classicthemerestorer.invicoextrabar",false);
pref("extensions.classicthemerestorer.invicobookbar",false);
pref("extensions.classicthemerestorer.invicoaddonbar",false);

pref("extensions.classicthemerestorer.closeicong",'closeicong_default');
pref("extensions.classicthemerestorer.athrobberurl","");

pref("extensions.classicthemerestorer.anewtaburlcb",false);
pref("extensions.classicthemerestorer.anewtaburl","about:newtab");

pref("extensions.classicthemerestorer.tabseparator","tabsep_default");

// Urlbar
pref("extensions.classicthemerestorer.starinurl",false);
pref("extensions.classicthemerestorer.feedinurl",false);
pref("extensions.classicthemerestorer.hideurelstop",false);
pref("extensions.classicthemerestorer.hideurelstop2",false);
pref("extensions.classicthemerestorer.hideurlgo",false);
pref("extensions.classicthemerestorer.hideurlsrg",false);
pref("extensions.classicthemerestorer.hideprbutton",false);
pref("extensions.classicthemerestorer.urlbardropm",false);
pref("extensions.classicthemerestorer.urlbardropm2",false);
pref("extensions.classicthemerestorer.altreaderico",false);

pref("extensions.classicthemerestorer.ib_nohovcolor",false);
pref("extensions.classicthemerestorer.ib_graycolor",false);
pref("extensions.classicthemerestorer.verifiedcolors",false);
pref("extensions.classicthemerestorer.ibinfoico",false);
pref("extensions.classicthemerestorer.faviconurl",false);
pref("extensions.classicthemerestorer.padlock","padlock_default");
pref("extensions.classicthemerestorer.padlockex",true);
pref("extensions.classicthemerestorer.icopageinfo",false);

pref("extensions.classicthemerestorer.extraurlkeycb",false);
pref("extensions.classicthemerestorer.locsearchbw10",false);

pref("extensions.classicthemerestorer.lbsbsize",false);
pref("extensions.classicthemerestorer.lbsize_minw",200);
pref("extensions.classicthemerestorer.lbsize_maxw",4000);
pref("extensions.classicthemerestorer.sbsize_minw",200);
pref("extensions.classicthemerestorer.sbsize_maxw",4000);

// Toolbar settings
pref("extensions.classicthemerestorer.aerocolors",false);
pref("extensions.classicthemerestorer.transpttbw10",false);
pref("extensions.classicthemerestorer.transpttbew10",false);
pref("extensions.classicthemerestorer.transptcw10",false);
pref("extensions.classicthemerestorer.nbiconsize",'small');

pref("extensions.classicthemerestorer.nobookbarbg",false);
pref("extensions.classicthemerestorer.bookbarfs",false);
pref("extensions.classicthemerestorer.hidenavbar",false);
pref("extensions.classicthemerestorer.nonavbarbg",false);
pref("extensions.classicthemerestorer.nonavborder",false);
pref("extensions.classicthemerestorer.nonavtbborder",false);
pref("extensions.classicthemerestorer.hidesbclose",false);
pref("extensions.classicthemerestorer.notextshadow",false);
pref("extensions.classicthemerestorer.chevronfix",false);
pref("extensions.classicthemerestorer.tbsep_winc",false);

pref("extensions.classicthemerestorer.dblclnewtab",false);
pref("extensions.classicthemerestorer.hidetbwot",false);
pref("extensions.classicthemerestorer.hidetbwote",true);
pref("extensions.classicthemerestorer.hidetbwote2",true);
pref("extensions.classicthemerestorer.notabfog",false);
pref("extensions.classicthemerestorer.notabbg",false);
pref("extensions.classicthemerestorer.hightabpososx",false);
pref("extensions.classicthemerestorer.alttabstb",false);
pref("extensions.classicthemerestorer.alttabstb2",true);

pref("extensions.classicthemerestorer.altmenubar",false);
pref("extensions.classicthemerestorer.altmbarpos",'altmbarpos0');
pref("extensions.classicthemerestorer.menubarfs",false);
pref("extensions.classicthemerestorer.menubarnofog",false);

pref("extensions.classicthemerestorer.closeabarbut",false);
pref("extensions.classicthemerestorer.highaddonsbar",false);
pref("extensions.classicthemerestorer.addonbarfs",false);
pref("extensions.classicthemerestorer.noaddonbarbg",false);

pref("extensions.classicthemerestorer.am_extrabars",1);
pref("extensions.classicthemerestorer.mbarposition","toolbar-menubar");
pref("extensions.classicthemerestorer.mbarpositionl","toolbar-menubar");
pref("extensions.classicthemerestorer.mbarforceleft",false);
pref("extensions.classicthemerestorer.mbarforceright",false);
pref("extensions.classicthemerestorer.navbarpad",false);
pref("extensions.classicthemerestorer.navbarpad_l",3);
pref("extensions.classicthemerestorer.navbarpad_r",3);
pref("extensions.classicthemerestorer.navbarmar_l",0);
pref("extensions.classicthemerestorer.navbarmar_r",0);

// Animation
pref("extensions.classicthemerestorer.tabthrobber","throbber_default");
pref("extensions.classicthemerestorer.bmanimation",true);
pref("extensions.classicthemerestorer.pananimation",true);
pref("extensions.classicthemerestorer.fsaduration",true);

// CTR area
pref("extensions.classicthemerestorer.toolsitem",true);
pref("extensions.classicthemerestorer.appmenuitem",true);
pref("extensions.classicthemerestorer.contextitem",false);
pref("extensions.classicthemerestorer.puictrbutton",false);
pref("extensions.classicthemerestorer.cuibuttons",true);
pref("extensions.classicthemerestorer.nodevtheme2",false);
pref("extensions.classicthemerestorer.restartapp",true);
pref("extensions.classicthemerestorer.pref_actindx",3);
pref("extensions.classicthemerestorer.pref_actindx2",0);

// Tab color settings
pref("extensions.classicthemerestorer.tabcolor_def",false);
pref("extensions.classicthemerestorer.tabcolor_act",false);
pref("extensions.classicthemerestorer.tabcolor_pen",false);
pref("extensions.classicthemerestorer.tabcolor_unr",false);
pref("extensions.classicthemerestorer.tabcolor_hov",false);

pref("extensions.classicthemerestorer.ntabcolor_def",false);
pref("extensions.classicthemerestorer.ntabcolor_hov",false);

pref("extensions.classicthemerestorer.ctab1",'#00FF00');
pref("extensions.classicthemerestorer.ctab2",'#007700');
pref("extensions.classicthemerestorer.ctabhov1",'#FFFFBB');
pref("extensions.classicthemerestorer.ctabhov2",'#FFFF00');
pref("extensions.classicthemerestorer.ctabact1",'#FF8800');
pref("extensions.classicthemerestorer.ctabact2",'#FF0000');
pref("extensions.classicthemerestorer.ctabpen1",'#00FF00');
pref("extensions.classicthemerestorer.ctabpen2",'#007700');
pref("extensions.classicthemerestorer.ctabunr1",'#00FF00');
pref("extensions.classicthemerestorer.ctabunr2",'#007700');
pref("extensions.classicthemerestorer.cntab1",'#00FF00');
pref("extensions.classicthemerestorer.cntab2",'#007700');
pref("extensions.classicthemerestorer.cntabhov1",'#FFFFBB');
pref("extensions.classicthemerestorer.cntabhov2",'#FFFF00');

pref("extensions.classicthemerestorer.tabtextc_def",false);
pref("extensions.classicthemerestorer.tabtextc_act",false);
pref("extensions.classicthemerestorer.tabtextc_pen",false);
pref("extensions.classicthemerestorer.tabtextc_unr",false);
pref("extensions.classicthemerestorer.tabtextc_hov",false);

pref("extensions.classicthemerestorer.ctabt",'#000000');
pref("extensions.classicthemerestorer.ctabhovt",'#000000');
pref("extensions.classicthemerestorer.ctabactt",'#000000');
pref("extensions.classicthemerestorer.ctabpent",'#000000');
pref("extensions.classicthemerestorer.ctabunrt",'#000000');

pref("extensions.classicthemerestorer.tabtextsh_def",false);
pref("extensions.classicthemerestorer.tabtextsh_act",false);
pref("extensions.classicthemerestorer.tabtextsh_pen",false);
pref("extensions.classicthemerestorer.tabtextsh_unr",false);
pref("extensions.classicthemerestorer.tabtextsh_hov",false);

pref("extensions.classicthemerestorer.ctabtsh",'#FFFFFF');
pref("extensions.classicthemerestorer.ctabhovtsh",'#FFFFFF');
pref("extensions.classicthemerestorer.ctabacttsh",'#FFFFFF');
pref("extensions.classicthemerestorer.ctabpentsh",'#FFFFFF');
pref("extensions.classicthemerestorer.ctabunrtsh",'#FFFFFF');

pref("extensions.classicthemerestorer.tabfbold_def",false);
pref("extensions.classicthemerestorer.tabfbold_act",false);
pref("extensions.classicthemerestorer.tabfbold_pen",false);
pref("extensions.classicthemerestorer.tabfbold_unr",false);
pref("extensions.classicthemerestorer.tabfbold_hov",false);

pref("extensions.classicthemerestorer.tabfita_def",false);
pref("extensions.classicthemerestorer.tabfita_act",false);
pref("extensions.classicthemerestorer.tabfita_pen",false);
pref("extensions.classicthemerestorer.tabfita_unr",false);
pref("extensions.classicthemerestorer.tabfita_hov",false);

pref("extensions.classicthemerestorer.tabc_act_tb",false);
pref("extensions.classicthemerestorer.tabc_hov_unr",false);
pref("extensions.classicthemerestorer.tabc_hov_unl",false);

pref("extensions.classicthemerestorer.optionsrem",true);
pref("extensions.classicthemerestorer.aboutprefs",'category-general');
pref("extensions.classicthemerestorer.aboutprefsInd",0);
pref("extensions.classicthemerestorer.aboutprefsww",700);
pref("extensions.classicthemerestorer.aboutprefswh",670);

// first run/reset preference
pref("extensions.classicthemerestorer.ctrreset",true);

==> classic-theme-restorer_1.5.2.orig.tar.gz: classic-theme-restorer-1.5.2/xpi/defaults/preferences/options.js <==
// tab settings
pref("extensions.classicthemerestorer.tabs","tabs_squared");
pref("extensions.classicthemerestorer.tabsontop",'unset');
pref("extensions.classicthemerestorer.ctabheightcb",false);
pref("extensions.classicthemerestorer.square_edges",false);
pref("extensions.classicthemerestorer.ctabheight",28);
pref("extensions.classicthemerestorer.ctabmwidth",100);
pref("extensions.classicthemerestorer.ctabwidth",210);
pref("extensions.classicthemerestorer.emptyfavico_t",'emptyfavico_t_none');
pref("extensions.classicthemerestorer.noemptypticon",false);
pref("extensions.classicthemerestorer.closetab","closetab_default");
pref("extensions.classicthemerestorer.closetabhfl",false);
pref("extensions.classicthemerestorer.closeonleft",false);
pref("extensions.classicthemerestorer.closetabbig",false);
pref("extensions.classicthemerestorer.closeicon",'closeicon_default');
pref("extensions.classicthemerestorer.tttitlebar",false);

//Appbutton settings
pref("extensions.classicthemerestorer.appbutton",'appbutton_v1');
pref("extensions.classicthemerestorer.appbuttonc",'appbuttonc_orange');
pref("extensions.classicthemerestorer.appbuttonct",false);
pref("extensions.classicthemerestorer.altabico",'altabico_white');
pref("extensions.classicthemerestorer.appbutmhi",false);
pref("extensions.classicthemerestorer.appbutbdl",false);
pref("extensions.classicthemerestorer.dblclclosefx",false);
pref("extensions.classicthemerestorer.appbclmmenus",true);
pref("extensions.classicthemerestorer.appbautocol",false);

pref("extensions.classicthemerestorer.appbuttontxt",'');

pref("extensions.classicthemerestorer.cappbutc1",'#00FF00');
pref("extensions.classicthemerestorer.cappbutc2",'#007700');

//General UI
pref("extensions.classicthemerestorer.smallnavbut",false);
pref("extensions.classicthemerestorer.bf_space",false);
pref("extensions.classicthemerestorer.backforward",false);
pref("extensions.classicthemerestorer.hide_bf_popup",false);
pref("extensions.classicthemerestorer.nbcompact",false);
pref("extensions.classicthemerestorer.statusbar",true);
pref("extensions.classicthemerestorer.noconicons",false);
pref("extensions.classicthemerestorer.altoptions",'options_default');
pref("extensions.classicthemerestorer.svgfilters",false);
pref("extensions.classicthemerestorer.combrelstop",false);
pref("extensions.classicthemerestorer.activndicat",false);
pref("extensions.classicthemerestorer.nbisizedelay",0);
pref("extensions.classicthemerestorer.findbar","findbar_default");
pref("extensions.classicthemerestorer.nav_txt_ico","icons");
pref("extensions.classicthemerestorer.iat_notf_vt",false);
pref("extensions.classicthemerestorer.wincontrols",false);
pref("extensions.classicthemerestorer.puibuttonsep",'puib_nosep');
pref("extensions.classicthemerestorer.oldtoplevimg",false);
pref("extensions.classicthemerestorer.altalertbox",false);
pref("extensions.classicthemerestorer.emptyfavico_g",'emptyfavico_g_def');
pref("extensions.classicthemerestorer.panelmenucol",false);
pref("extensions.classicthemerestorer.cpanelmenus",false);
pref("extensions.classicthemerestorer.hidezoomres",false);
pref("extensions.classicthemerestorer.alt_newtabp",false);
pref("extensions.classicthemerestorer.nosnippets",false);
pref("extensions.classicthemerestorer.ctroldsearch",false);
pref("extensions.classicthemerestorer.ctroldsearchc",false);
pref("extensions.classicthemerestorer.osearch_meoit",false);
pref("extensions.classicthemerestorer.osearch_dm",false);
pref("extensions.classicthemerestorer.osearch_iwidth",true);
pref("extensions.classicthemerestorer.addonversion",true);
pref("extensions.classicthemerestorer.alt_addonsm",false);
pref("extensions.classicthemerestorer.am_nowarning",false);
pref("extensions.classicthemerestorer.am_compact",false);
pref("extensions.classicthemerestorer.am_compact2",true);
pref("extensions.classicthemerestorer.am_highlight",false);
pref("extensions.classicthemerestorer.am_buticons",false);
pref("extensions.classicthemerestorer.am_hovshowb",false);
pref("extensions.classicthemerestorer.alt_addonsp",false);
pref("extensions.classicthemerestorer.hiderecentbm",false);
pref("extensions.classicthemerestorer.hideeditbm",false);
pref("extensions.classicthemerestorer.bmbutpanelm",false);
pref("extensions.classicthemerestorer.bmbunsortbm",false);
pref("extensions.classicthemerestorer.bmbunsortbm2",true);
pref("extensions.classicthemerestorer.bmbviewbmtb",false);
pref("extensions.classicthemerestorer.bmbviewbmsb",false);
pref("extensions.classicthemerestorer.bmbnounsort",false);
pref("extensions.classicthemerestorer.bmbutnotext",false);
pref("extensions.classicthemerestorer.skipprintpr",false);
pref("extensions.classicthemerestorer.tbconmenu",false);
pref("extensions.classicthemerestorer.noresizerxp",false);
pref("extensions.classicthemerestorer.pmhidelabels",false);
pref("extensions.classicthemerestorer.menupopupscr",false);
pref("extensions.classicthemerestorer.hideprivmask",false);
pref("extensions.classicthemerestorer.urlresults",false);

pref("extensions.classicthemerestorer.tabmokcolor",false);
pref("extensions.classicthemerestorer.tabmokcolor2",false);
pref("extensions.classicthemerestorer.tabmokcolor3",false);
pref("extensions.classicthemerestorer.tabmokcolor4",false);

pref("extensions.classicthemerestorer.invicomenubar",false);
pref("extensions.classicthemerestorer.invicotabsbar",false);
pref("extensions.classicthemerestorer.inviconavbar",false);
pref("extensions.classicthemerestorer.invicoextrabar",false);
pref("extensions.classicthemerestorer.invicobookbar",false);
pref("extensions.classicthemerestorer.invicoaddonbar",false);

pref("extensions.classicthemerestorer.closeicong",'closeicong_default');
pref("extensions.classicthemerestorer.athrobberurl","");

pref("extensions.classicthemerestorer.anewtaburlcb",false);
pref("extensions.classicthemerestorer.anewtaburl","about:newtab");

pref("extensions.classicthemerestorer.tabseparator","tabsep_default");

// Urlbar
pref("extensions.classicthemerestorer.starinurl",false);
pref("extensions.classicthemerestorer.feedinurl",false);
pref("extensions.classicthemerestorer.hideurelstop",false);
pref("extensions.classicthemerestorer.hideurelstop2",false);
pref("extensions.classicthemerestorer.hideurlgo",false);
pref("extensions.classicthemerestorer.hideurlsrg",false);
pref("extensions.classicthemerestorer.hideprbutton",false);
pref("extensions.classicthemerestorer.urlbardropm",false);
pref("extensions.classicthemerestorer.urlbardropm2",false);
pref("extensions.classicthemerestorer.altreaderico",false);
pref("extensions.classicthemerestorer.altautocompl",false);

pref("extensions.classicthemerestorer.ib_nohovcolor",false);
pref("extensions.classicthemerestorer.ib_graycolor",false);
pref("extensions.classicthemerestorer.verifiedcolors",false);
pref("extensions.classicthemerestorer.ibinfoico",false);
pref("extensions.classicthemerestorer.ibinfoico2",false);
pref("extensions.classicthemerestorer.iblabels",false);
pref("extensions.classicthemerestorer.faviconurl",false);
pref("extensions.classicthemerestorer.padlock","padlock_default");
pref("extensions.classicthemerestorer.padlockex",true);
pref("extensions.classicthemerestorer.icopageinfo",false);

pref("extensions.classicthemerestorer.extraurlkeycb",false);
pref("extensions.classicthemerestorer.extraurltarget",'tab');
pref("extensions.classicthemerestorer.locsearchbw10",false);

pref("extensions.classicthemerestorer.lbsbsize",false);
pref("extensions.classicthemerestorer.lbsize_minw",200);
pref("extensions.classicthemerestorer.lbsize_maxw",4000);
pref("extensions.classicthemerestorer.sbsize_minw",200);
pref("extensions.classicthemerestorer.sbsize_maxw",4000);
pref("extensions.classicthemerestorer.lbsbradius",false);
pref("extensions.classicthemerestorer.lbradius_left",0);
pref("extensions.classicthemerestorer.lbradius_right",0);
pref("extensions.classicthemerestorer.sbradius_left",0);
pref("extensions.classicthemerestorer.sbradius_right",0);

// Toolbar settings
pref("extensions.classicthemerestorer.aerocolors",false);
pref("extensions.classicthemerestorer.transpttbw10",false);
pref("extensions.classicthemerestorer.transpttbew10",false);
pref("extensions.classicthemerestorer.transptcw10",false);
pref("extensions.classicthemerestorer.nbiconsize",'small');

pref("extensions.classicthemerestorer.nobookbarbg",false);
pref("extensions.classicthemerestorer.bookbarfs",false);
pref("extensions.classicthemerestorer.hidenavbar",false);
pref("extensions.classicthemerestorer.nonavbarbg",false);
pref("extensions.classicthemerestorer.nonavborder",false);
pref("extensions.classicthemerestorer.nonavtbborder",false);
pref("extensions.classicthemerestorer.hidesbclose",false);
pref("extensions.classicthemerestorer.notextshadow",false);
pref("extensions.classicthemerestorer.chevronfix",false);
pref("extensions.classicthemerestorer.tbsep_winc",false);

pref("extensions.classicthemerestorer.dblclnewtab",false);
pref("extensions.classicthemerestorer.hidetbwot",false);
pref("extensions.classicthemerestorer.hidetbwote",true);
pref("extensions.classicthemerestorer.hidetbwote2",true);
pref("extensions.classicthemerestorer.notabfog",false);
pref("extensions.classicthemerestorer.notabbg",false);
pref("extensions.classicthemerestorer.hightabpososx",false);
pref("extensions.classicthemerestorer.alttabstb",false);
pref("extensions.classicthemerestorer.alttabstb2",true);

pref("extensions.classicthemerestorer.altmenubar",false);
pref("extensions.classicthemerestorer.altmbarpos",'altmbarpos0');
pref("extensions.classicthemerestorer.menubarfs",false);
pref("extensions.classicthemerestorer.menubarnofog",false);

pref("extensions.classicthemerestorer.closeabarbut",false);
pref("extensions.classicthemerestorer.highaddonsbar",false);
pref("extensions.classicthemerestorer.lessaddonsbar",false);
pref("extensions.classicthemerestorer.addonbarfs",false);
pref("extensions.classicthemerestorer.noaddonbarbg",false);

pref("extensions.classicthemerestorer.am_extrabars",1);
pref("extensions.classicthemerestorer.mbarposition","toolbar-menubar");
pref("extensions.classicthemerestorer.mbarpositionl","toolbar-menubar");
pref("extensions.classicthemerestorer.mbarforceleft",false);
pref("extensions.classicthemerestorer.mbarforceright",false);
pref("extensions.classicthemerestorer.navbarpad",false);
pref("extensions.classicthemerestorer.navbarpad_l",3);
pref("extensions.classicthemerestorer.navbarpad_r",3);
pref("extensions.classicthemerestorer.navbarmar_l",0);
pref("extensions.classicthemerestorer.navbarmar_r",0);

// Animation
pref("extensions.classicthemerestorer.tabthrobber","throbber_default");
pref("extensions.classicthemerestorer.bmanimation",true);
pref("extensions.classicthemerestorer.pananimation",true);
pref("extensions.classicthemerestorer.fsaduration",true);
pref("extensions.classicthemerestorer.html5warning",true);

// CTR area
pref("extensions.classicthemerestorer.toolsitem",true);
pref("extensions.classicthemerestorer.appmenuitem",true);
pref("extensions.classicthemerestorer.contextitem",false);
pref("extensions.classicthemerestorer.puictrbutton",false);
pref("extensions.classicthemerestorer.cuibuttons",true);
pref("extensions.classicthemerestorer.nodevtheme2",false);
pref("extensions.classicthemerestorer.restartapp",true);
pref("extensions.classicthemerestorer.pref_actindx",3);
pref("extensions.classicthemerestorer.pref_actindx2",0);

// Tab color settings
pref("extensions.classicthemerestorer.tabcolor_def",false);
pref("extensions.classicthemerestorer.tabcolor_act",false);
pref("extensions.classicthemerestorer.tabcolor_pen",false);
pref("extensions.classicthemerestorer.tabcolor_unr",false);
pref("extensions.classicthemerestorer.tabcolor_hov",false);

pref("extensions.classicthemerestorer.ntabcolor_def",false);
pref("extensions.classicthemerestorer.ntabcolor_hov",false);

pref("extensions.classicthemerestorer.ctab1",'#00FF00');
pref("extensions.classicthemerestorer.ctab2",'#007700');
pref("extensions.classicthemerestorer.ctabhov1",'#FFFFBB');
pref("extensions.classicthemerestorer.ctabhov2",'#FFFF00');
pref("extensions.classicthemerestorer.ctabact1",'#FF8800');
pref("extensions.classicthemerestorer.ctabact2",'#FF0000');
pref("extensions.classicthemerestorer.ctabpen1",'#00FF00');
pref("extensions.classicthemerestorer.ctabpen2",'#007700');
pref("extensions.classicthemerestorer.ctabunr1",'#00FF00');
pref("extensions.classicthemerestorer.ctabunr2",'#007700');
pref("extensions.classicthemerestorer.cntab1",'#00FF00');
pref("extensions.classicthemerestorer.cntab2",'#007700');
pref("extensions.classicthemerestorer.cntabhov1",'#FFFFBB');
pref("extensions.classicthemerestorer.cntabhov2",'#FFFF00');

pref("extensions.classicthemerestorer.tabtextc_def",false);
pref("extensions.classicthemerestorer.tabtextc_act",false);
pref("extensions.classicthemerestorer.tabtextc_pen",false);
pref("extensions.classicthemerestorer.tabtextc_unr",false);
pref("extensions.classicthemerestorer.tabtextc_hov",false);

pref("extensions.classicthemerestorer.ctabt",'#000000');
pref("extensions.classicthemerestorer.ctabhovt",'#000000');
pref("extensions.classicthemerestorer.ctabactt",'#000000');
pref("extensions.classicthemerestorer.ctabpent",'#000000');
pref("extensions.classicthemerestorer.ctabunrt",'#000000');

pref("extensions.classicthemerestorer.tabtextsh_def",false);
pref("extensions.classicthemerestorer.tabtextsh_act",false);
pref("extensions.classicthemerestorer.tabtextsh_pen",false);
pref("extensions.classicthemerestorer.tabtextsh_unr",false);
pref("extensions.classicthemerestorer.tabtextsh_hov",false);

pref("extensions.classicthemerestorer.ctabtsh",'#FFFFFF');
pref("extensions.classicthemerestorer.ctabhovtsh",'#FFFFFF');
pref("extensions.classicthemerestorer.ctabacttsh",'#FFFFFF');
pref("extensions.classicthemerestorer.ctabpentsh",'#FFFFFF');
pref("extensions.classicthemerestorer.ctabunrtsh",'#FFFFFF');

pref("extensions.classicthemerestorer.tabfbold_def",false);
pref("extensions.classicthemerestorer.tabfbold_act",false);
pref("extensions.classicthemerestorer.tabfbold_pen",false);
pref("extensions.classicthemerestorer.tabfbold_unr",false);
pref("extensions.classicthemerestorer.tabfbold_hov",false);

pref("extensions.classicthemerestorer.tabfita_def",false);
pref("extensions.classicthemerestorer.tabfita_act",false);
pref("extensions.classicthemerestorer.tabfita_pen",false);
pref("extensions.classicthemerestorer.tabfita_unr",false);
pref("extensions.classicthemerestorer.tabfita_hov",false);

pref("extensions.classicthemerestorer.tabc_act_tb",false);
pref("extensions.classicthemerestorer.tabc_hov_unr",false);
pref("extensions.classicthemerestorer.tabc_hov_unl",false);

pref("extensions.classicthemerestorer.optionsrem",true);
pref("extensions.classicthemerestorer.aboutprefs",'category-general');
pref("extensions.classicthemerestorer.aboutprefsInd",0);
pref("extensions.classicthemerestorer.aboutprefsww",850);
pref("extensions.classicthemerestorer.aboutprefswh",670);

// first run/reset preference
pref("extensions.classicthemerestorer.ctrreset",true);

// other
pref("extensions.classicthemerestorer.cstatextlb",false);
